@@ -3,11 +3,11 @@
 #
 package DBI::Shell::Timing;
 
-use strict;
-use vars qw(@ISA $VERSION);
-use Benchmark qw(timeit timestr);
+our $VERSION = '11.98'; # VERSION
 
-$VERSION = sprintf( "%d.%02d", q$Revision: 11.91 $ =~ /(\d+)\.(\d+)/ );
+use strict;
+use vars qw(@ISA);
+use Benchmark qw(timeit timestr);
 
 sub init {
 	my ($self, $sh, @arg)  = @_;
